Package: projoint
Type: Package
Title: Conjoint Analysis with Reliability Correction and Visualization
Version: 1.1.4
Date: 2026-08-28
Maintainer: Yusaku Horiuchi <yusaku.horiuchi@gmail.com>
Authors@R: 
    c(
      person("Yusaku", "Horiuchi", email = "yusaku.horiuchi@gmail.com",
             role = c("aut", "cre"),
             comment = c(ORCID = "0000-0003-0295-4089")),
      person("Aaron", "Kaufman", email = "aaronkaufman@nyu.edu",
             role = "aut",
             comment = c(ORCID = "0000-0003-3688-0428")),
      person("Gary", "King", email = "king@harvard.edu",
             role = "aut",
             comment = c(ORCID = "0000-0002-5327-7631"))
    )
Author: Yusaku Horiuchi [aut, cre] (ORCID:
    <https://orcid.org/0000-0003-0295-4089>),
  Aaron Kaufman [aut] (ORCID: <https://orcid.org/0000-0003-3688-0428>),
  Gary King [aut] (ORCID: <https://orcid.org/0000-0002-5327-7631>)
Description: Provides tools for analyzing data generated from conjoint survey experiments, a method widely used in the social sciences for studying multidimensional preferences. The package implements estimation of marginal means (MMs) and average marginal component effects (AMCEs), with corrections for measurement error. Methods include profile-level and choice-level estimators, bias correction using intra-respondent reliability (IRR), and visualization utilities. For details on the methodology, see Clayton, Horiuchi, Kaufman, King, and Komisarchik (2025) <https://gking.harvard.edu/conjointE>.
Imports: dplyr (>= 1.1.2), readr, rlang, tidyr, stringr, tidyselect,
        estimatr, ggthemes, ggplot2, stats, tibble, methods, MASS,
        forcats, scales
Suggests: tidyverse, knitr, rmarkdown, downloadthis, patchwork,
        testthat (>= 3.0.0), DiagrammeR
VignetteBuilder: knitr
License: MIT + file LICENSE
Encoding: UTF-8
RoxygenNote: 7.3.3
Config/testthat/edition: 3
URL: https://yhoriuchi.github.io/projoint/
Depends: R (>= 4.1.0)
LazyData: false
BugReports: https://github.com/yhoriuchi/projoint/issues
NeedsCompilation: no
Packaged: 2026-08-28 19:00:57 UTC; yh25m
Repository: CRAN
Date/Publication: 2026-08-28 19:30:02 UTC
