#' @importFrom stats cov
#' @importFrom stats sd
#' @importFrom ggplot2 %+replace%

if (getRversion() >= "2.15.1") {
  utils::globalVariables(c(
    ".", 
    "1", 
    "2", 
    "aes",
    "agree",
    "att",
    "att_1",
    "att_2",
    "att_comb",
    "att_level",
    "att_level_choose",
    "att_level_choose_baseline",
    "att_level_labels",
    "att_level_notchoose",
    "att_level_notchoose_baseline",
    "attribute",
    "attribute_id",
    "attribute_id_arranged",
    "attribute_name",
    "baseline",
    "code",
    "conf.high",
    "conf.low",
    "cov",
    "cov_mm_tau",
    "estimate",
    "estimate_0",
    "estimate_1",
    "estimates",
    "estimand",
    "id",
    "irr",
    "level",
    "level_id",
    "level_id_arranged",
    "level_name",
    "name",
    "outcome_qnum",
    "predicted",
    "predict",
    "profile",
    "projoint_results",
    "qoi",
    "qoi_1",
    "qoi_2",
    "qoi_choose",
    "qoi_choose_1",
    "qoi_choose_2",
    "qoi_notchoose",
    "qoi_notchoose_1",
    "qoi_notchoose_2",
    "response",
    "response_order",
    "sd",
    "se",
    "se_0",
    "se_1",
    "selected",
    "selected_1",
    "selected_2",
    "selected_repeated",
    "std.error",
    "t1",
    "t2",
    "task",
    "task1_y",
    "task2_y",
    "ties",
    "value",
    "vcov",
    "x",
    "y",
    "y_same"
  ))
}
